@@ -2,19 +2,28 @@ from __future__ import print_function, division, absolute_import
 
 from contextlib import contextmanager
 import socket
+import sys
 import threading
 from time import sleep
 
 import pytest
 from tornado import gen
 
-from distributed import Scheduler, Worker, Client
+from distributed import Scheduler, Worker, Client, config
 from distributed.core import rpc
 from distributed.metrics import time
-from distributed.utils_test import (cluster, loop, gen_cluster,
-        gen_test, wait_for_port, slow)
+from distributed.utils_test import (cluster, gen_cluster,
+                                    gen_test, wait_for_port, new_config,
+                                    tls_only_security)
+from distributed.utils_test import loop # flake8: noqa
 from distributed.utils import get_ip
 
+
+def test_bare_cluster(loop):
+    with cluster(nworkers=10) as (s, _):
+        pass
+
+
 def test_cluster(loop):
     with cluster() as (s, [a, b]):
         with rpc(s['address']) as s:
@@ -24,13 +33,14 @@ def test_cluster(loop):
 
 
 @gen_cluster(client=True)
-def test_gen_cluster(e, s, a, b):
-    assert isinstance(e, Client)
+def test_gen_cluster(c, s, a, b):
+    assert isinstance(c, Client)
     assert isinstance(s, Scheduler)
     for w in [a, b]:
         assert isinstance(w, Worker)
     assert s.ncores == {w.address: w.ncores for w in [a, b]}
 
+
 @gen_cluster(client=False)
 def test_gen_cluster_without_client(s, a, b):
     assert isinstance(s, Scheduler)
@@ -38,6 +48,20 @@ def test_gen_cluster_without_client(s, a, b):
         assert isinstance(w, Worker)
     assert s.ncores == {w.address: w.ncores for w in [a, b]}
 
+
+@gen_cluster(client=True, scheduler='tls://127.0.0.1',
+             ncores=[('tls://127.0.0.1', 1), ('tls://127.0.0.1', 2)],
+             security=tls_only_security())
+def test_gen_cluster_tls(e, s, a, b):
+    assert isinstance(e, Client)
+    assert isinstance(s, Scheduler)
+    assert s.address.startswith('tls://')
+    for w in [a, b]:
+        assert isinstance(w, Worker)
+        assert w.address.startswith('tls://')
+    assert s.ncores == {w.address: w.ncores for w in [a, b]}
+
+
 @gen_test()
 def test_gen_test():
     yield gen.sleep(0.01)
@@ -88,3 +112,16 @@ def test_wait_for_port():
         wait_for_port(s1.getsockname())
         t2 = time()
         assert t2 - t1 <= 2.0
+
+
+def test_new_config():
+    c = config.copy()
+    with new_config({'xyzzy': 5}):
+        assert config == {'xyzzy': 5}
+
+    assert config == c
+    assert 'xyzzy' not in config
+
+
+if sys.version_info >= (3, 5):
+    from distributed.tests.py3_test_utils_tst import *  # flake8: noqa
